@@ -20,6 +20,8 @@
  *
  */
 
+#include <config.h>
+
 #include "bg-pictures-source.h"
 
 #include "cc-background-item.h"
@@ -188,6 +190,7 @@ picture_scaled (GObject *source_object,
 
 
   g_object_unref (pixbuf);
+  g_object_unref (item);
 }
 
 static void
@@ -411,8 +414,7 @@ dir_enum_async_ready (GObject      *source,
 
   if (err)
     {
-      if (!g_error_matches (err, G_IO_ERROR, G_IO_ERROR_NOT_FOUND) &&
-          !g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+      if (!g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED))
         g_warning ("Could not fill pictures source: %s", err->message);
       g_error_free (err);
       return;
@@ -427,6 +429,7 @@ dir_enum_async_ready (GObject      *source,
                                       priv->cancellable,
                                       file_info_async_ready,
                                       user_data);
+  g_object_unref (enumerator);
 }
 
 char *
@@ -609,6 +612,8 @@ bg_pictures_source_init (BgPicturesSource *self)
 					     NULL);
 
   pictures_path = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
+  g_mkdir_with_parents (pictures_path, USER_DIR_MODE);
+
   dir = g_file_new_for_path (pictures_path);
   g_file_enumerate_children_async (dir,
 				   ATTRIBUTES,
@@ -630,6 +635,8 @@ bg_pictures_source_init (BgPicturesSource *self)
   g_object_unref (dir);
 
   cache_path = bg_pictures_source_get_cache_path ();
+  g_mkdir_with_parents (cache_path, USER_DIR_MODE);
+
   dir = g_file_new_for_path (cache_path);
   g_file_enumerate_children_async (dir,
 				   ATTRIBUTES,
