@@ -67,7 +67,6 @@ struct _CcBackgroundChooserDialogPrivate
 #endif
 
   GnomeDesktopThumbnailFactory *thumb_factory;
-  gint current_source;
 
   GCancellable *copy_cancellable;
 
@@ -102,9 +101,6 @@ cc_background_chooser_dialog_realize (GtkWidget *widget)
       gtk_widget_set_size_request (GTK_WIDGET (chooser), (gint) (0.5 * width), (gint) (0.9 * height));
     }
 
-  gtk_icon_view_set_model (GTK_ICON_VIEW (chooser->priv->icon_view),
-                           GTK_TREE_MODEL (bg_source_get_liststore (BG_SOURCE (chooser->priv->wallpapers_source))));
-
   GTK_WIDGET_CLASS (cc_background_chooser_dialog_parent_class)->realize (widget);
 }
 
@@ -125,6 +121,9 @@ cc_background_chooser_dialog_dispose (GObject *object)
   g_clear_object (&priv->pictures_source);
   g_clear_object (&priv->colors_source);
   g_clear_object (&priv->wallpapers_source);
+#ifdef HAVE_LIBSOCIALWEB
+  g_clear_object (&priv->flickr_source);
+#endif
   g_clear_object (&priv->thumb_factory);
 
   G_OBJECT_CLASS (cc_background_chooser_dialog_parent_class)->dispose (object);
@@ -300,6 +299,7 @@ cc_background_chooser_dialog_init (CcBackgroundChooserDialog *chooser)
   gtk_grid_set_row_spacing (GTK_GRID (grid), 12);
   gtk_grid_set_column_spacing (GTK_GRID (grid), 0);
   gtk_container_add (GTK_CONTAINER (vbox), grid);
+  gtk_widget_set_size_request (grid, 860, 550);
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_set_homogeneous (GTK_BOX (hbox), TRUE);
@@ -350,10 +350,6 @@ cc_background_chooser_dialog_init (CcBackgroundChooserDialog *chooser)
   gtk_widget_set_hexpand (priv->sw_content, TRUE);
   gtk_widget_set_vexpand (priv->sw_content, TRUE);
   gtk_container_add (GTK_CONTAINER (grid), priv->sw_content);
-  g_object_set (priv->sw_content,
-                "width-request", 860,
-                "height-request", 550,
-                NULL);
 
   priv->empty_pictures_box = gtk_grid_new ();
   gtk_widget_set_no_show_all (priv->empty_pictures_box, TRUE);
@@ -363,10 +359,6 @@ cc_background_chooser_dialog_init (CcBackgroundChooserDialog *chooser)
   context = gtk_widget_get_style_context (priv->empty_pictures_box);
   gtk_style_context_add_class (context, "dim-label");
   gtk_container_add (GTK_CONTAINER (grid), priv->empty_pictures_box);
-  g_object_set (priv->empty_pictures_box,
-                "width-request", 860,
-                "height-request", 550,
-                NULL);
   img = gtk_image_new_from_icon_name ("emblem-photos-symbolic", GTK_ICON_SIZE_DIALOG);
   gtk_image_set_pixel_size (GTK_IMAGE (img), 64);
   gtk_widget_set_halign (img, GTK_ALIGN_END);
@@ -438,6 +430,7 @@ cc_background_chooser_dialog_init (CcBackgroundChooserDialog *chooser)
   gtk_dialog_set_default_response (GTK_DIALOG (chooser), GTK_RESPONSE_OK);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (chooser), GTK_RESPONSE_OK, FALSE);
 
+  on_view_toggled (GTK_TOGGLE_BUTTON (button1), chooser);
   gtk_widget_show_all (vbox);
 }
 
