@@ -796,6 +796,8 @@ cc_background_item_finalize (GObject *object)
         g_free (item->priv->secondary_color);
         g_free (item->priv->mime_type);
         g_free (item->priv->size);
+        g_free (item->priv->source_url);
+        g_free (item->priv->source_xml);
 
         if (item->priv->bg != NULL)
                 g_object_unref (item->priv->bg);
@@ -892,9 +894,9 @@ cc_background_item_dump (CcBackgroundItem *item)
 	g_debug ("flags:\t\t\t%s", flags->str);
 	g_string_free (flags, TRUE);
 	if (priv->primary_color)
-		g_debug ("pcolor:\t\t%s", priv->primary_color);
+		g_debug ("pcolor:\t\t\t%s", priv->primary_color);
 	if (priv->secondary_color)
-		g_debug ("scolor:\t\t%s", priv->secondary_color);
+		g_debug ("scolor:\t\t\t%s", priv->secondary_color);
 	g_debug ("placement:\t\t%s", enum_to_str (G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE, priv->placement));
 	g_debug ("shading:\t\t%s", enum_to_str (G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING, priv->shading));
 	if (priv->source_url)
