@@ -92,6 +92,7 @@ typedef struct
 struct _CcInfoPanelPrivate
 {
   GtkBuilder    *builder;
+  GtkWidget     *extra_options_dialog;
   char          *gnome_version;
   char          *gnome_distributor;
   char          *gnome_date;
@@ -461,6 +462,7 @@ cc_info_panel_dispose (GObject *object)
   g_clear_object (&priv->pk_proxy);
   g_clear_object (&priv->pk_transaction_proxy);
   g_clear_pointer (&priv->graphics_data, graphics_data_free);
+  g_clear_pointer (&priv->extra_options_dialog, gtk_widget_destroy);
 
   G_OBJECT_CLASS (cc_info_panel_parent_class)->dispose (object);
 }
@@ -1305,7 +1307,7 @@ on_extra_options_button_clicked (GtkWidget    *button,
   GtkWidget *dialog;
   GtkWidget *combo_box;
 
-  dialog = GTK_WIDGET (gtk_builder_get_object (self->priv->builder, "extra_options_dialog"));
+  dialog = self->priv->extra_options_dialog;
   combo_box = GTK_WIDGET (gtk_builder_get_object (self->priv->builder, "media_other_type_combobox"));
   gtk_window_set_transient_for (GTK_WINDOW (dialog),
                                 GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self))));
@@ -1566,7 +1568,7 @@ info_panel_setup_overview (CcInfoPanel  *self)
   gtk_label_set_markup (GTK_LABEL (widget), self->priv->graphics_data->hardware_string);
 
   widget = WID ("info_vbox");
-  gtk_widget_reparent (widget, (GtkWidget *) self);
+  gtk_container_add (GTK_CONTAINER (self), widget);
 
   refresh_update_button (self);
 }
@@ -1849,6 +1851,8 @@ cc_info_panel_init (CcInfoPanel *self)
       return;
     }
 
+  self->priv->extra_options_dialog = WID ("extra_options_dialog");
+
   self->priv->graphics_data = get_graphics_data ();
 
   widget = WID ("updates_button");
