@@ -68,6 +68,7 @@ struct _CcPowerPanelPrivate
   GSettings     *session_settings;
   GCancellable  *cancellable;
   GtkBuilder    *builder;
+  GtkWidget     *automatic_suspend_dialog;
   UpClient      *up_client;
   GDBusProxy    *screen_proxy;
   GDBusProxy    *kbd_proxy;
@@ -137,6 +138,7 @@ cc_power_panel_dispose (GObject *object)
       g_object_unref (priv->cancellable);
       priv->cancellable = NULL;
     }
+  g_clear_pointer (&priv->automatic_suspend_dialog, gtk_widget_destroy);
   g_clear_object (&priv->builder);
   g_clear_object (&priv->screen_proxy);
   g_clear_object (&priv->kbd_proxy);
@@ -457,6 +459,43 @@ add_battery (CcPowerPanel *panel, UpDevice *device)
   gtk_widget_set_visible (priv->battery_section, TRUE);
 }
 
+static const char *
+kind_to_description (UpDeviceKind kind)
+{
+  switch (kind)
+    {
+      case UP_DEVICE_KIND_MOUSE:
+        /* TRANSLATORS: secondary battery */
+        return N_("Wireless mouse");
+      case UP_DEVICE_KIND_KEYBOARD:
+        /* TRANSLATORS: secondary battery */
+        return N_("Wireless keyboard");
+      case UP_DEVICE_KIND_UPS:
+        /* TRANSLATORS: secondary battery */
+        return N_("Uninterruptible power supply");
+      case UP_DEVICE_KIND_PDA:
+        /* TRANSLATORS: secondary battery */
+        return N_("Personal digital assistant");
+      case UP_DEVICE_KIND_PHONE:
+        /* TRANSLATORS: secondary battery */
+        return N_("Cellphone");
+      case UP_DEVICE_KIND_MEDIA_PLAYER:
+        /* TRANSLATORS: secondary battery */
+        return N_("Media player");
+      case UP_DEVICE_KIND_TABLET:
+        /* TRANSLATORS: secondary battery */
+        return N_("Tablet");
+      case UP_DEVICE_KIND_COMPUTER:
+        /* TRANSLATORS: secondary battery */
+        return N_("Computer");
+      default:
+        /* TRANSLATORS: secondary battery, misc */
+        return N_("Battery");
+    }
+
+  g_assert_not_reached ();
+}
+
 static void
 add_device (CcPowerPanel *panel, UpDevice *device)
 {
@@ -470,55 +509,27 @@ add_device (CcPowerPanel *panel, UpDevice *device)
   GString *status;
   GString *description;
   gdouble percentage;
+  gchar *name;
   gchar *s;
   gboolean show_caution = FALSE;
 
+  name = NULL;
   g_object_get (device,
                 "kind", &kind,
                 "percentage", &percentage,
                 "state", &state,
+                "model", &name,
                 NULL);
 
-  switch (kind)
-    {
-      case UP_DEVICE_KIND_MOUSE:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Wireless mouse"));
-        break;
-      case UP_DEVICE_KIND_KEYBOARD:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Wireless keyboard"));
-        break;
-      case UP_DEVICE_KIND_UPS:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Uninterruptible power supply"));
-        show_caution = TRUE;
-        break;
-      case UP_DEVICE_KIND_PDA:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Personal digital assistant"));
-        break;
-      case UP_DEVICE_KIND_PHONE:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Cellphone"));
-        break;
-      case UP_DEVICE_KIND_MEDIA_PLAYER:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Media player"));
-        break;
-      case UP_DEVICE_KIND_TABLET:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Tablet"));
-        break;
-      case UP_DEVICE_KIND_COMPUTER:
-        /* TRANSLATORS: secondary battery */
-        description = g_string_new (_("Computer"));
-        break;
-      default:
-        /* TRANSLATORS: secondary battery, misc */
-        description = g_string_new (_("Battery"));
-        break;
-    }
+  if (kind == UP_DEVICE_KIND_UPS)
+    show_caution = TRUE;
+
+  if (name == NULL || *name == '\0')
+    description = g_string_new (_(kind_to_description (kind)));
+  else
+    description = g_string_new (name);
+
+  g_free (name);
 
   switch (state)
     {
@@ -1772,7 +1783,7 @@ activate_row (CcPowerPanel *self,
 
   if (row == GTK_LIST_BOX_ROW (priv->automatic_suspend_row))
     {
-      w = WID (priv->builder, "automatic_suspend_dialog");
+      w = priv->automatic_suspend_dialog;
       toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
       gtk_window_set_transient_for (GTK_WINDOW (w), GTK_WINDOW (toplevel));
       gtk_window_set_modal (GTK_WINDOW (w), TRUE);
@@ -1983,7 +1994,7 @@ add_automatic_suspend_section (CcPowerPanel *self)
   gtk_size_group_add_widget (priv->row_sizegroup, row);
   gtk_widget_show_all (widget);
 
-  dialog = WID (priv->builder, "automatic_suspend_dialog");
+  dialog = priv->automatic_suspend_dialog;
   sw = WID (priv->builder, "automatic_suspend_close");
   g_signal_connect_swapped (sw, "clicked", G_CALLBACK (gtk_widget_hide), dialog);
   g_signal_connect (dialog, "delete-event", G_CALLBACK (gtk_widget_hide_on_delete), NULL);
@@ -2180,6 +2191,8 @@ cc_power_panel_init (CcPowerPanel *self)
       return;
     }
 
+  priv->automatic_suspend_dialog = WID (priv->builder, "automatic_suspend_dialog");
+
   priv->cancellable = g_cancellable_new ();
 
   g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
@@ -2236,10 +2249,7 @@ cc_power_panel_init (CcPowerPanel *self)
                     G_CALLBACK (on_content_size_changed), NULL);
   gtk_widget_show (box);
   gtk_container_add (GTK_CONTAINER (self), box);
-  g_object_ref (widget);
-  gtk_widget_unparent (widget);
   gtk_container_add (GTK_CONTAINER (box), widget);
-  g_object_unref (widget);
 
   priv->focus_adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (box));
   gtk_container_set_focus_vadjustment (GTK_CONTAINER (widget), priv->focus_adjustment);
