@@ -41,6 +41,9 @@ CC_PANEL_REGISTER (CcSharingPanel, cc_sharing_panel)
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), CC_TYPE_SHARING_PANEL, CcSharingPanelPrivate))
 
 
+static void cc_sharing_panel_setup_label_with_hostname (CcSharingPanel *self, GtkWidget *label);
+
+
 static GtkWidget *
 _gtk_builder_get_widget (GtkBuilder  *builder,
                          const gchar *name)
@@ -201,6 +204,14 @@ cc_sharing_panel_run_dialog (CcSharingPanel *self,
 
   dialog = WID (dialog_name);
 
+  /* ensure labels with the hostname are updated if the hostname has changed */
+  cc_sharing_panel_setup_label_with_hostname (self,
+                                              WID ("screen-sharing-label"));
+  cc_sharing_panel_setup_label_with_hostname (self, WID ("remote-login-label"));
+  cc_sharing_panel_setup_label_with_hostname (self,
+                                              WID ("personal-file-sharing-label"));
+
+
   parent = cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (self)));
 
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
@@ -373,25 +384,11 @@ cc_sharing_panel_setup_bluetooth_sharing_dialog (CcSharingPanel *self)
   g_signal_connect_swapped (priv->bluetooth_killswitch, "state-changed",
                             G_CALLBACK (bluetooth_state_changed), self);
 
-  cc_sharing_panel_bind_switch_to_label (self,
-                                         WID ("share-public-folder-switch"),
-                                         WID ("bluetooth-sharing-status-label"));
-
-  cc_sharing_panel_bind_switch_to_widgets (WID ("share-public-folder-switch"),
-                                           WID ("only-share-trusted-devices-box"),
-                                           NULL);
-
   cc_sharing_panel_bind_switch_to_widgets (WID ("save-received-files-to-downloads-switch"),
                                            WID ("receive-files-grid"),
                                            NULL);
 
   settings = g_settings_new (FILE_SHARING_SCHEMA_ID);
-  g_settings_bind (settings, "bluetooth-enabled",
-                   WID ("share-public-folder-switch"), "active",
-                   G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind (settings, "bluetooth-require-pairing",
-                   WID ("only-share-trusted-devices-switch"), "active",
-                   G_SETTINGS_BIND_DEFAULT);
   g_settings_bind (settings, "bluetooth-obexpush-enabled",
                    WID ("save-received-files-to-downloads-switch"), "active",
                    G_SETTINGS_BIND_DEFAULT);
@@ -414,6 +411,9 @@ cc_sharing_panel_add_folder (GtkWidget      *button,
   GtkWidget *dialog;
   GtkListStore *store;
   gchar *folder;
+  GtkTreeIter iter;
+  gboolean valid;
+  gboolean matching;
 
   dialog = gtk_file_chooser_dialog_new (_("Choose a Folder"),
                                         GTK_WINDOW (gtk_widget_get_toplevel (button)),
@@ -430,7 +430,21 @@ cc_sharing_panel_add_folder (GtkWidget      *button,
 
   folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog));
 
-  if (folder && !g_str_equal (folder, ""))
+  for (valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
+       valid;
+       valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter))
+    {
+      gchar *string;
+
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &string, -1);
+      matching = (g_strcmp0 (string, folder) != 0);
+      g_free (string);
+
+      if (matching)
+        break;
+    }
+
+  if (!matching && folder && !g_str_equal (folder, ""))
     gtk_list_store_insert_with_values (store, NULL, -1, 0, folder, -1);
 
   g_free (folder);
@@ -586,12 +600,21 @@ cc_sharing_panel_setup_label (GtkLabel    *label,
                               const gchar *hostname)
 {
   gchar *text;
+  const gchar *format;
 
-  hostname = g_strdup (hostname);
+  format = g_object_get_data (G_OBJECT (label), "format-label");
+  if (!format)
+    {
+      format = gtk_label_get_label (label);
 
-  text = g_strdup_printf (gtk_label_get_label (GTK_LABEL (label)), hostname, hostname);
+      /* save the original format string so that it can be used again later */
+      g_object_set_data_full (G_OBJECT (label), "format-label",
+                              g_strdup (format), g_free);
+    }
 
-  gtk_label_set_label (GTK_LABEL (label), text);
+  text = g_strdup_printf (format, hostname, hostname);
+
+  gtk_label_set_label (label, text);
 
   g_free (text);
 }
@@ -918,10 +941,6 @@ cc_sharing_panel_setup_screen_sharing_dialog (CcSharingPanel *self)
                                            WID ("remote-control-box"),
                                            NULL);
 
-  cc_sharing_panel_bind_switch_to_widgets (WID ("remote-control-switch"),
-                                           WID ("remote-control-grid"),
-                                           NULL);
-
   cc_sharing_panel_bind_switch_to_widgets (WID ("remote-control-require-password-switch"),
                                            WID ("password-grid"),
                                            NULL);
