@@ -107,6 +107,8 @@ struct _CcUaPanelPrivate
 
   GList *sections;
   GList *sections_reverse;
+
+  GSList *toplevels;
 };
 
 static void
@@ -115,6 +117,8 @@ cc_ua_panel_dispose (GObject *object)
   CcUaPanelPrivate *priv = CC_UA_PANEL (object)->priv;
 
   g_clear_object (&priv->builder);
+  g_slist_free_full (priv->toplevels, gtk_widget_destroy);
+  priv->toplevels = NULL;
 
   g_clear_object (&priv->wm_settings);
   g_clear_object (&priv->a11y_settings);
@@ -404,15 +408,6 @@ activate_row (CcUaPanel *self, GtkListBoxRow *row)
   gtk_window_present (GTK_WINDOW (dialog));
 }
 
-static void
-mnemonic_activate (GtkLabel *label, gboolean cycling, CcUaPanel *self)
-{
-  GtkWidget *row;
-
-  row = gtk_widget_get_parent (GTK_WIDGET (label));
-  activate_row (self, GTK_LIST_BOX_ROW (row));
-}
-
 static void
 cc_ua_panel_init_seeing (CcUaPanel *self)
 {
@@ -446,9 +441,6 @@ cc_ua_panel_init_seeing (CcUaPanel *self)
                                 priv->interface_settings,
                                 NULL);
 
-  g_signal_connect (WID ("heading_large_text"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
-
   /* zoom */
 
   g_settings_bind_with_mapping (priv->application_settings, "screen-magnifier-enabled",
@@ -458,8 +450,6 @@ cc_ua_panel_init_seeing (CcUaPanel *self)
                                 NULL, NULL, NULL);
 
   g_object_set_data (G_OBJECT (WID ("row_zoom")), "dialog-id", "zoom");
-  g_signal_connect (WID ("heading_zoom"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 
   /* screen reader */
 
@@ -474,14 +464,13 @@ cc_ua_panel_init_seeing (CcUaPanel *self)
                    G_SETTINGS_BIND_DEFAULT);
 
   dialog = WID ("screen_reader_dialog");
+  priv->toplevels = g_slist_prepend (priv->toplevels, dialog);
 
   g_object_set_data (G_OBJECT (WID ("row_screen_reader")), "dialog", dialog);
   g_signal_connect_swapped (WID ("screen_reader_done"), "clicked",
                             G_CALLBACK (gtk_widget_hide), dialog);
   g_signal_connect (dialog, "delete-event",
                     G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-  g_signal_connect (WID ("heading_screen_reader"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 
   /* sound keys */
 
@@ -496,14 +485,13 @@ cc_ua_panel_init_seeing (CcUaPanel *self)
                    G_SETTINGS_BIND_DEFAULT);
 
   dialog = WID ("sound_keys_dialog");
+  priv->toplevels = g_slist_prepend (priv->toplevels, dialog);
 
   g_object_set_data (G_OBJECT (WID ("row_sound_keys")), "dialog", dialog);
   g_signal_connect_swapped (WID ("sound_keys_done"), "clicked",
                             G_CALLBACK (gtk_widget_hide), dialog);
   g_signal_connect (dialog, "delete-event",
                     G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-  g_signal_connect (WID ("heading_sound_keys"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 }
 
 /* hearing/sound section */
@@ -583,6 +571,7 @@ cc_ua_panel_init_hearing (CcUaPanel *self)
                     "toggled", G_CALLBACK (visual_bell_type_toggle_cb), self);
 
   dialog = WID ("visual_alerts_dialog");
+  priv->toplevels = g_slist_prepend (priv->toplevels, dialog);
 
   g_object_set_data (G_OBJECT (WID ("row_visual_alerts")), "dialog", dialog);
 
@@ -593,8 +582,6 @@ cc_ua_panel_init_hearing (CcUaPanel *self)
 
   g_signal_connect (WID ("visual_alerts_test_button"),
                     "clicked", G_CALLBACK (gdk_beep), NULL);
-  g_signal_connect (WID ("heading_visual_alerts"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 }
 
 /* typing/keyboard section */
@@ -713,6 +700,7 @@ cc_ua_panel_init_keyboard (CcUaPanel *self)
   g_object_bind_property (sw, "active", w, "sensitive", G_BINDING_SYNC_CREATE);
 
   dialog = WID ("typing_dialog");
+  priv->toplevels = g_slist_prepend (priv->toplevels, dialog);
 
   g_object_set_data (G_OBJECT (WID ("row_accessx")), "dialog", dialog);
 
@@ -720,8 +708,6 @@ cc_ua_panel_init_keyboard (CcUaPanel *self)
                             G_CALLBACK (gtk_widget_hide), dialog);
   g_signal_connect (dialog, "delete-event",
                     G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-  g_signal_connect (WID ("heading_accessx"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 }
 
 /* mouse/pointing & clicking section */
@@ -796,6 +782,7 @@ cc_ua_panel_init_mouse (CcUaPanel *self)
   g_object_bind_property (sw, "active", w, "sensitive", G_BINDING_SYNC_CREATE);
 
   dialog = WID ("pointing_dialog");
+  priv->toplevels = g_slist_prepend (priv->toplevels, dialog);
 
   g_object_set_data (G_OBJECT (WID ("row_click_assist")), "dialog", dialog);
 
@@ -803,8 +790,6 @@ cc_ua_panel_init_mouse (CcUaPanel *self)
                             G_CALLBACK (gtk_widget_hide), dialog);
   g_signal_connect (dialog, "delete-event",
                     G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-  g_signal_connect (WID ("heading_click_assist"), "mnemonic-activate",
-                    G_CALLBACK (mnemonic_activate), self);
 }
 
 static void
@@ -864,5 +849,5 @@ cc_ua_panel_init (CcUaPanel *self)
   priv->focus_adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (panel));
   gtk_container_set_focus_vadjustment (GTK_CONTAINER (content), priv->focus_adjustment);
 
-  gtk_widget_reparent (panel, GTK_WIDGET (self));
+  gtk_container_add (GTK_CONTAINER (self), panel);
 }
