@@ -74,7 +74,7 @@ struct CalibArea
 #define WINDOW_OPACITY          0.9
 
 /* Timeout parameters */
-#define MAX_TIME                15000 /* 5000 = 5 sec */
+#define MAX_TIME                15000 /* 15000 = 15 sec */
 #define END_TIME                750   /*  750 = 0.75 sec */
 
 /* Text printed on screen */
@@ -131,9 +131,9 @@ resize_display(CalibArea *calib_area)
     {
       gint i = calib_area->calibrator.num_clicks;
       set_display_size(calib_area, width, height);
-      cc_target_actor_move (CC_TARGET_ACTOR (calib_area->target),
-                            calib_area->X[i],
-                            calib_area->Y[i]);
+      cc_target_actor_move_center (CC_TARGET_ACTOR (calib_area->target),
+                                   calib_area->X[i],
+                                   calib_area->Y[i]);
     }
 }
 
@@ -304,11 +304,19 @@ on_button_press_event(ClutterActor       *actor,
   /* Check matching device ID if a device ID was provided */
   if (area->device_id > -1)
     {
-      GdkDevice *device;
+      ClutterInputDevice *device;
 
-      device = gdk_event_get_source_device ((GdkEvent *) event);
-      if (device != NULL && gdk_x11_device_get_id (device) != area->device_id)
+      device = clutter_event_get_source_device ((ClutterEvent *) event);
+      if (device != NULL && clutter_input_device_get_device_id (device) != area->device_id) {
+        char *name;
+
+        g_object_get (G_OBJECT (device), "name", &name, NULL);
+        g_debug ("Ignoring input from device %s (%d)",
+                 name,
+                 clutter_input_device_get_device_id (device));
+        g_free (name);
         return FALSE;
+      }
     }
 
   /* Handle click */
@@ -338,10 +346,9 @@ on_button_press_event(ClutterActor       *actor,
       return FALSE;
     }
 
-  cc_target_actor_move (CC_TARGET_ACTOR (area->target),
-                        area->X[num_clicks],
-                        area->Y[num_clicks]);
-
+  cc_target_actor_move_center (CC_TARGET_ACTOR (area->target),
+                               area->X[num_clicks],
+                               area->Y[num_clicks]);
 
   return FALSE;
 }
@@ -504,11 +511,6 @@ set_up_stage (CalibArea *calib_area, ClutterActor *stage)
                     G_CALLBACK (on_allocation_changed),
                     calib_area);
 
-  calib_area->calibrator.geometry.x = clutter_actor_get_x (stage);
-  calib_area->calibrator.geometry.y = clutter_actor_get_y (stage);
-  calib_area->calibrator.geometry.width = clutter_actor_get_width (stage);
-  calib_area->calibrator.geometry.height = clutter_actor_get_height (stage);
-
   clutter_color_from_string (&color, "#000");
   color.alpha = WINDOW_OPACITY * 255;
   clutter_actor_set_background_color (stage, &color);
@@ -715,6 +717,8 @@ calib_area_new (GdkScreen      *screen,
                                rect.width,
                                rect.height);
 
+  calib_area->calibrator.geometry = rect;
+
   set_up_stage (calib_area, stage);
 
   g_signal_connect (calib_area->window,
