@@ -30,9 +30,12 @@
 #include "cc-shell-log.h"
 #include "cc-window.h"
 
+#if defined(HAVE_CHEESE) || defined(HAVE_WACOM)
+#include <clutter-gtk/clutter-gtk.h>
+#endif /* HAVE_CHEESE || HAVE_WACOM */
+
 #ifdef HAVE_CHEESE
 #include <cheese-gtk.h>
-#include <clutter-gtk/clutter-gtk.h>
 #endif /* HAVE_CHEESE */
 
 struct _CcApplicationPrivate
@@ -94,6 +97,27 @@ help_activated (GSimpleAction *action,
                 GDK_CURRENT_TIME, NULL);
 }
 
+static void
+launch_panel_activated (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
+{
+  CcApplication *self = CC_APPLICATION (user_data);
+  GError *error = NULL;
+  gchar *panel_id;
+  GVariant *parameters;
+
+  g_variant_get (parameter, "(&s@av)", &panel_id, &parameters);
+  g_debug ("gnome-control-center: 'launch-panel' activated for panel '%s' with %"G_GSIZE_FORMAT" arguments",
+      panel_id, g_variant_n_children (parameters));
+  if (!cc_shell_set_active_panel_from_id (CC_SHELL (self->priv->window), panel_id, parameters, &error))
+    {
+      g_warning ("Failed to activate the '%s' panel: %s", panel_id, error->message);
+      g_error_free (error);
+    }
+  g_variant_unref (parameters);
+}
+
 static int
 cc_application_command_line (GApplication *application,
                              GApplicationCommandLine *command_line)
@@ -104,18 +128,22 @@ cc_application_command_line (GApplication *application,
   int retval = 0;
   GOptionContext *context;
   GError *error = NULL;
+  GVariantBuilder *flags_builder;
 
   verbose = FALSE;
   show_overview = FALSE;
   show_help = FALSE;
   start_panels = NULL;
 
+  flags_builder = g_variant_builder_new (G_VARIANT_TYPE_VARDICT);
+
   argv = g_application_command_line_get_arguments (command_line, &argc);
 
   context = g_option_context_new (N_("- Settings"));
   g_option_context_add_main_entries (context, all_options, GETTEXT_PACKAGE);
   g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
+  cc_panel_loader_add_option_groups (context, flags_builder);
   g_option_context_set_help_enabled (context, FALSE);
 
   start_panels = NULL;
@@ -188,6 +216,9 @@ cc_application_command_line (GApplication *application,
     {
       const char *start_id;
       GError *err = NULL;
+      GVariant *parameters;
+      GVariantBuilder *builder;
+      int i;
 
       start_id = start_panels[0];
 
@@ -196,7 +227,13 @@ cc_application_command_line (GApplication *application,
       else
         g_debug ("No extra argument");
 
-      if (!cc_shell_set_active_panel_from_id (CC_SHELL (self->priv->window), start_id, (const gchar**)start_panels+1, &err))
+      builder = g_variant_builder_new (G_VARIANT_TYPE ("av"));
+      g_variant_builder_add (builder, "v", g_variant_builder_end (flags_builder));
+
+      for (i = 1; start_panels[i] != NULL; i++)
+        g_variant_builder_add (builder, "v", g_variant_new_string (start_panels[i]));
+      parameters = g_variant_builder_end (builder);
+      if (!cc_shell_set_active_panel_from_id (CC_SHELL (self->priv->window), start_id, parameters, &err))
         {
           g_warning ("Could not load setting panel \"%s\": %s", start_id,
                      (err) ? err->message : "Unknown error");
@@ -252,13 +289,13 @@ cc_application_startup (GApplication *application)
 
   G_APPLICATION_CLASS (cc_application_parent_class)->startup (application);
 
-#ifdef HAVE_CHEESE
+#if defined(HAVE_CHEESE) || defined(HAVE_WACOM)
   if (gtk_clutter_init (NULL, NULL) != CLUTTER_INIT_SUCCESS)
     {
       g_critical ("Unable to initialize Clutter");
       return;
     }
-#endif /* HAVE_CHEESE */
+#endif /* HAVE_CHEESE || HAVE_WACOM */
 
   /* register a symbolic icon size for use in sidebar lists */
   gtk_icon_size_register ("cc-sidebar-list", 24, 24);
@@ -273,6 +310,15 @@ cc_application_startup (GApplication *application)
   g_signal_connect (action, "activate", G_CALLBACK (cc_application_quit), self);
   g_object_unref (action);
 
+  /* Launch panel by id. The parameter is a (panel_id, array_of_panel_parameters)
+   * tuple. The GVariant-containing array usually is just the same array of
+   * strings that would be generated by passing panel-specific arguments on
+   * the command line. */
+  action = g_simple_action_new ("launch-panel", G_VARIANT_TYPE ("(sav)"));
+  g_action_map_add_action (G_ACTION_MAP (application), G_ACTION (action));
+  g_signal_connect (action, "activate", G_CALLBACK (launch_panel_activated), self);
+  g_object_unref (action);
+
   menu = g_menu_new ();
 
   section = g_menu_new ();
